summaryrefslogtreecommitdiffstats
path: root/src/usr/runtime/hdatservice.C
diff options
context:
space:
mode:
authorMatt Ploetz <maploetz@us.ibm.com>2013-09-24 11:03:02 -0500
committerA. Patrick Williams III <iawillia@us.ibm.com>2013-10-12 14:51:14 -0500
commit4e536844c21b0ab7c256e49c63e8e9520c9e1d19 (patch)
tree03fa743c3e3f5c00cf1d44a936a3c92c7673b48c /src/usr/runtime/hdatservice.C
parenteffbdc22da60af7ae67f69005f63a6a6e4db773d (diff)
downloadtalos-hostboot-4e536844c21b0ab7c256e49c63e8e9520c9e1d19.tar.gz
talos-hostboot-4e536844c21b0ab7c256e49c63e8e9520c9e1d19.zip
Hardware Reconfigure loop and Istepdispatcher redesign
Change-Id: Icc037be6b0eac67d1b5196180f8a53f083afa085 RTC: 34055 Reviewed-on: http://gfw160.austin.ibm.com:8080/gerrit/6324 Tested-by: Jenkins Server Reviewed-by: A. Patrick Williams III <iawillia@us.ibm.com>
Diffstat (limited to 'src/usr/runtime/hdatservice.C')
-rw-r--r--src/usr/runtime/hdatservice.C12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/usr/runtime/hdatservice.C b/src/usr/runtime/hdatservice.C
index be8b912fd..15ccf6953 100644
--- a/src/usr/runtime/hdatservice.C
+++ b/src/usr/runtime/hdatservice.C
@@ -473,10 +473,10 @@ errlHndl_t hdatService::loadHostData(void)
payload_kind = TARGETING::PAYLOAD_KIND_PHYP;
#endif
//If PHYP or Sapphire w/FSP
if( (TARGETING::PAYLOAD_KIND_PHYP == payload_kind ) ||
((TARGETING::PAYLOAD_KIND_SAPPHIRE == payload_kind ) &&
- !INITSERVICE::spLess()))
+ INITSERVICE::spBaseServicesEnabled()))
{
// PHYP
TARGETING::ATTR_PAYLOAD_BASE_type payload_base
@@ -578,10 +578,10 @@ errlHndl_t hdatService::getHostDataSection( SectionId i_section,
// we're all done
break;
}
//If payload is not (PHYP or Sapphire w/fsp)
else if( !((TARGETING::PAYLOAD_KIND_PHYP == payload_kind ) ||
((TARGETING::PAYLOAD_KIND_SAPPHIRE == payload_kind ) &&
- !INITSERVICE::spLess())))
+ INITSERVICE::spBaseServicesEnabled())))
{
TRACFCOMP( g_trac_runtime, "getHostDataSection> There is no host data for PAYLOAD_KIND=%d", payload_kind );
/*@
@@ -1202,10 +1202,10 @@ errlHndl_t hdatService::updateHostDataSectionActual( SectionId i_section,
// we're all done -- don't need to do anything
break;
}
//If payload is not (PHYP or Sapphire w/fsp)
else if( !((TARGETING::PAYLOAD_KIND_PHYP == payload_kind ) ||
((TARGETING::PAYLOAD_KIND_SAPPHIRE == payload_kind ) &&
- !INITSERVICE::spLess())))
+ INITSERVICE::spBaseServicesEnabled())))
{
TRACFCOMP( g_trac_runtime, "get_host_data_section> There is no host data for PAYLOAD_KIND=%d", payload_kind );
/*@
@@ -473,10 +473,10 @@ errlHndl_t hdatService::loadHostData(void)
payload_kind = TARGETING::PAYLOAD_KIND_PHYP;
#endif
- //If PHYP or Sapphire w/FSP
+ //If PHYP or Sapphire w/SP Base Services
if( (TARGETING::PAYLOAD_KIND_PHYP == payload_kind ) ||
((TARGETING::PAYLOAD_KIND_SAPPHIRE == payload_kind ) &&
@@ -578,10 +578,10 @@ errlHndl_t hdatService::getHostDataSection( SectionId i_section,
break;
}
- //If payload is not (PHYP or Sapphire w/fsp)
+ //If payload is not (PHYP or Sapphire w/SP Base Services )
else if( !((TARGETING::PAYLOAD_KIND_PHYP == payload_kind ) ||
((TARGETING::PAYLOAD_KIND_SAPPHIRE == payload_kind ) &&
@@ -1202,10 +1202,10 @@ errlHndl_t hdatService::updateHostDataSectionActual( SectionId i_section,
break;
}
- //If payload is not (PHYP or Sapphire w/fsp)
+ //If payload is not (PHYP or Sapphire w/SP Base Services)
else if( !((TARGETING::PAYLOAD_KIND_PHYP == payload_kind ) ||
((TARGETING::PAYLOAD_KIND_SAPPHIRE == payload_kind ) &&
OpenPOWER on IntegriCloud